@@ -3,7 +3,7 @@
  *
  * remotetcp.h: tcp/telnet remote control
  *
- * Copyright (C) 2002-2012 Oliver Endriss <o.endriss@gmx.de>
+ * Copyright (C) 2002-2015 Oliver Endriss <o.endriss@gmx.de>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@
 #define __PLUGIN_REMOTETCP_H
 
 
-#include <vdr/svdrp.h>
+#include "compat.h"
 #include "remote.h"
 
 
@@ -36,7 +36,7 @@ class cTcpRemote : protected cRemoteDevTty
 {
 private:
   cTtyStatus *cstatus;
-  cSocket *csock;
+  cSocketRemote *csock;
 
 protected:
   virtual uint64_t getKey(void);
